Analogs Finder
##############

.. image:: https://travis-ci.com/NostrumBioDiscovery/analogs_finder.svg?branch=master
       :target: https://travis-ci.com/NostrumBioDiscovery/analogs_finder

.. image:: https://anaconda.org/nostrumbiodiscovery/analogs_finder/badges/version.svg
       :target: https://anaconda.org/nostrumbiodiscovery/analogs_finder

.. image:: https://img.shields.io/github/last-commit/NostrumBioDiscovery/analogs_finder.svg
       :target: https://anaconda.org/nostrumbiodiscovery/analogs_finder

.. image:: https://img.shields.io/github/commit-activity/m/NostrumBioDiscovery/analogs_finder.svg
       :target: https://anaconda.org/nostrumbiodiscovery/analogs_finder

.. image:: https://codecov.io/gh/NostrumBioDiscovery/analogs_finder/branch/master/graph/badge.svg
       :target: https://anaconda.org/nostrumbiodiscovery/analogs_finder

Description
##############

Analogs finder is a python based query-search engine for drug discovery. It allows the user to perform queries based on molecule similarity or substructure matching to retrieve similar analogs from your initial molecule.

.. figure:: docs/_images/query_result.png
    :scale: 80%
    :align: center

Installation
##############

1) conda install -c NostrumBioDiscovery analogs_finder

2) export SCHRODINGER=/opt/schrodinger2019-1/

To use as Python module
########################

https://nostrumbiodiscovery.github.io/analogs_finder/tutorial/api_tutorial/index.html


To use from Command Line
#############################

https://nostrumbiodiscovery.github.io/analogs_finder/tutorial/command_line_tutorial/index.html

